import request from '@/utils/request'

// 查询地块信息列表
export function listField(query) {
  return request({
    url: '/base/field/list',
    method: 'get',
    params: query
  })
}

// 查询地块信息详细
export function getField(id) {
  return request({
    url: '/base/field/' + id,
    method: 'get'
  })
}


// 查询地块设备绑定信息
export function getDeviceField(id) {
  return request({
    url: '/base/field/device/' + id,
    method: 'get'
  })
}

// 查询地块设备未绑定信息
export function getDeviceUnField(id) {
  return request({
    url: '/base/field/unDevice/' + id,
    method: 'get'
  })
}

// 查询地块人员未绑定信息
export function getDeviceUnUser(id) {
  return request({
    url: '/base/field/unUser/' + id,
    method: 'get'
  })
}

// 查询地块设备绑定信息
export function getUserField(id) {
  return request({
    url: '/base/field/person/' + id,
    method: 'get'
  })
}


// 新增地块信息
export function addField(data) {
  return request({
    url: '/base/field',
    method: 'post',
    data: data
  })
}

// 修改地块信息
export function updateField(data) {
  return request({
    url: '/base/field',
    method: 'put',
    data: data
  })
}

// 删除地块信息
export function delField(id) {
  return request({
    url: '/base/field/' + id,
    method: 'delete'
  })
}

// 绑定地块设备信息
export function bindFieldDevice(id) {
  return request({
    url: '/base/field/bindFieldDevice/' + id,
    method: 'put'
  })
}

// 绑定地块人员信息
export function bindFieldUser(id) {
  return request({
    url: '/base/field/bindFieldPerson/' + id,
    method: 'put'
  })
}



// 解绑地块设备信息
export function unbindFieldDevice(id) {
  return request({
    url: '/base/field/unbindFieldDevice/' + id,
    method: 'put'
  })
}


// 解绑地块人员信息
export function unbindFieldUser(id) {
  return request({
    url: '/base/field/unbindFieldPerson/' + id,
    method: 'put'
  })
}


// 查询地块列表
export function listFieldName(query) {
  return request({
    url: '/base/field/listName',
    method: 'get',
    params: query
  })
}
